@@ -31,13 +31,13 @@ class DjangoRQ(Queue):
     def __init__(self, *args, **kwargs):
         autocommit = kwargs.pop('autocommit', None)
         self._autocommit = get_commit_mode() if autocommit is None else autocommit
+
         return super(DjangoRQ, self).__init__(*args, **kwargs)
 
     def original_enqueue_call(self, *args, **kwargs):
         return super(DjangoRQ, self).enqueue_call(*args, **kwargs)
 
     def enqueue_call(self, *args, **kwargs):
-        # print args, kwargs
         if self._autocommit:
             return self.original_enqueue_call(*args, **kwargs)
         else:
@@ -60,7 +60,13 @@ def get_redis_connection(config):
             # is a pluggable backend that return its Redis connection as
             # its `client`
             try:
-                return cache.client.client
+                # To get Redis connection on django-redis >= 3.4.0
+                # we need to use cache.client.get_client() instead of
+                # cache.client.client used in older versions
+                try:
+                    return cache.client.get_client()
+                except AttributeError:
+                    return cache.client.client
             except NotImplementedError:
                 pass
         else:
@@ -99,6 +105,9 @@ def get_queue(name='default', default_timeout=None, async=None,
     if async is None:
         async = QUEUES[name].get('ASYNC', True)
 
+    if default_timeout is None:
+        default_timeout = QUEUES[name].get('DEFAULT_TIMEOUT')
+
     return DjangoRQ(name, default_timeout=default_timeout,
                     connection=get_connection(name), async=async,
                     autocommit=autocommit)
