@@ -31,8 +31,7 @@ QUEUES = settings.RQ_QUEUES
 
 
 def access_self():
-    job = get_current_job()
-    return job.id
+    return get_current_job().id
 
 
 def divide(a, b):
@@ -151,7 +150,6 @@ class QueuesTest(TestCase):
         """
         self.assertRaises(ValueError, get_queues, 'default', 'test')
 
-
     def test_get_unique_connection_configs(self):
         connection_params_1 = {
             'HOST': 'localhost',
@@ -167,8 +165,13 @@ class QueuesTest(TestCase):
             'default': connection_params_1,
             'test': connection_params_2
         }
-        self.assertEqual(get_unique_connection_configs(config),
-                         [connection_params_1, connection_params_2])
+        unique_configs = get_unique_connection_configs(config)
+        self.assertEqual(len(unique_configs), 2)
+        self.assertIn(connection_params_1, unique_configs)
+        self.assertIn(connection_params_2, unique_configs)
+
+        # self.assertEqual(get_unique_connection_configs(config),
+        #                  [connection_params_1, connection_params_2])
         config = {
             'default': connection_params_1,
             'test': connection_params_1
@@ -182,16 +185,16 @@ class QueuesTest(TestCase):
         Checks whether asynchronous settings work
         """
         # Make sure async is not set by default
-        defaultQueue = get_queue('default')
-        self.assertTrue(defaultQueue._async)
+        default_queue = get_queue('default')
+        self.assertTrue(default_queue._async)
 
         # Make sure async override works
-        defaultQueueAsync = get_queue('default', async=False)
-        self.assertFalse(defaultQueueAsync._async)
+        default_queue_async = get_queue('default', async=False)
+        self.assertFalse(default_queue_async._async)
 
         # Make sure async setting works
-        asyncQueue = get_queue('async')
-        self.assertFalse(asyncQueue._async)
+        async_queue = get_queue('async')
+        self.assertFalse(async_queue._async)
 
     @override_settings(RQ={'AUTOCOMMIT': False})
     def test_autocommit(self):
@@ -213,6 +216,13 @@ class QueuesTest(TestCase):
         queues = get_queues()
         self.assertFalse(queues[0]._autocommit)
 
+    def test_default_timeout(self):
+        """Ensure DEFAULT_TIMEOUT are properly parsed."""
+        queue = get_queue()
+        self.assertEqual(queue._default_timeout, 500)
+        queue = get_queue('test1')
+        self.assertEqual(queue._default_timeout, 400)
+
 
 @override_settings(RQ={'AUTOCOMMIT': True})
 class DecoratorTest(TestCase):
@@ -295,7 +305,7 @@ class ViewTest(TestCase):
         """
         def failing_job():
             raise ValueError
-        
+
         queue = get_queue('default')
         queue_index = get_failed_queue_index('default')
         job = queue.enqueue(failing_job)
@@ -321,6 +331,66 @@ class ViewTest(TestCase):
         self.assertFalse(Job.exists(job.id, connection=queue.connection))
         self.assertNotIn(job.id, queue.job_ids)
 
+    def test_action_delete_jobs(self):
+        queue = get_queue('django_rq_test')
+        queue_index = get_queue_index('django_rq_test')
+
+        # enqueue some jobs
+        job_ids = []
+        for _ in range(0, 3):
+            job = queue.enqueue(access_self)
+            job_ids.append(job.id)
+
+        # remove those jobs using view
+        self.client.post(reverse('rq_actions', args=[queue_index]),
+                         {'action': 'delete', 'job_ids': job_ids})
+
+        # check if jobs are removed
+        for job_id in job_ids:
+            self.assertFalse(Job.exists(job_id, connection=queue.connection))
+            self.assertNotIn(job_id, queue.job_ids)
+
+    def test_action_requeue_jobs(self):
+        def failing_job():
+            raise ValueError
+
+        queue = get_queue('django_rq_test')
+        failed_queue_index = get_failed_queue_index('django_rq_test')
+
+        # enqueue some jobs that will fail
+        jobs = []
+        job_ids = []
+        for _ in range(0, 3):
+            job = queue.enqueue(failing_job)
+            jobs.append(job)
+            job_ids.append(job.id)
+
+        # do those jobs = fail them
+        worker = get_worker('django_rq_test')
+        worker.work(burst=True)
+
+        # check if all jobs are really failed
+        for job in jobs:
+            self.assertTrue(job.is_failed)
+
+        # renqueue failed jobs from failed queue
+        self.client.post(reverse('rq_actions', args=[failed_queue_index]),
+                         {'action': 'requeue', 'job_ids': job_ids})
+
+        # check if we requeue all failed jobs
+        for job in jobs:
+            self.assertFalse(job.is_failed)
+
+    def test_clear_queue(self):
+        """Test that the queue clear actually clears the queue."""
+        queue = get_queue('django_rq_test')
+        queue_index = get_queue_index('django_rq_test')
+        job = queue.enqueue(access_self)
+        self.client.post(reverse('rq_clear', args=[queue_index]),
+                         {'post': 'yes'})
+        self.assertFalse(Job.exists(job.id, connection=queue.connection))
+        self.assertNotIn(job.id, queue.job_ids)
+
 
 class ThreadQueueTest(TestCase):
 
@@ -345,11 +415,14 @@ class ThreadQueueTest(TestCase):
         job = queue.enqueue(divide, 1, b=1)
         self.assertTrue(job is None)
         delayed_queue = thread_queue.get_queue()
-        self.assertEqual(delayed_queue[0], (
-            queue,
-            (),
-            {'args': (1,), 'result_ttl': None, 'timeout': None, 'func': divide, 'kwargs': {'b': 1}}
-        ))
+        self.assertEqual(delayed_queue[0][0], queue)
+        self.assertEqual(delayed_queue[0][1], ())
+        kwargs = delayed_queue[0][2]
+        self.assertEqual(kwargs['args'], (1,))
+        self.assertEqual(kwargs['result_ttl'], None)
+        self.assertEqual(kwargs['kwargs'], {'b': 1})
+        self.assertEqual(kwargs['func'], divide)
+        self.assertEqual(kwargs['timeout'], None)
 
     def test_commit(self):
         """
@@ -438,7 +511,7 @@ class RedisCacheTest(TestCase):
         Test that the USE_REDIS_CACHE option for configuration works.
         """
         queueName = 'django-redis-cache'
-        queue = get_queue(queueName )
+        queue = get_queue(queueName)
         connection_kwargs = queue.connection.connection_pool.connection_kwargs
         self.assertEqual(queue.name, queueName)
 
